@@ -56,8 +56,8 @@ class Elpa(package.Package):
       dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
       incdirs = [os.path.join(self.packagedir,'include'),self.packagedir]
     else:
-      dirs = self.GenerateGuesses('Primme',archdir)
-      incdirs = self.GenerateGuesses('Primme',archdir,'include')
+      dirs = self.GenerateGuesses('elpa',archdir)
+      incdirs = self.GenerateGuesses('elpa',archdir,'include')
 
     libs = self.packagelibs
     if not libs:
@@ -100,7 +100,7 @@ class Elpa(package.Package):
 
     # Build package
     extra_fcflags = ' -fallow-argument-mismatch' if petsc.isGfortran100plus() else ''
-    confopt = '--prefix='+prefixdir+' CC="'+petsc.cc+'" CFLAGS="'+petsc.cc_flags+'" F77="'+petsc.fc+'" FFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+extra_fcflags+'" FC="'+petsc.fc+'" FCFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+extra_fcflags+'" LIBS="'+petsc.blaslapack_lib+'" SCALAPACK_LDFLAGS="'+petsc.scalapack_lib+'" --disable-sse --disable-sse-assembly --disable-avx --disable-avx2 --disable-avx512'
+    confopt = '--prefix='+prefixdir+' CC="'+petsc.cc+'" CFLAGS="'+petsc.cc_flags.replace('-fvisibility=hidden','')+'" F77="'+petsc.fc+'" FFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+extra_fcflags+'" FC="'+petsc.fc+'" FCFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+extra_fcflags+'" LIBS="'+petsc.blaslapack_lib+'" SCALAPACK_LDFLAGS="'+petsc.scalapack_lib+'" --disable-sse --disable-sse-assembly --disable-avx --disable-avx2 --disable-avx512'
     if petsc.mpiuni or petsc.msmpi:
       confopt = confopt+' --with-mpi=no'
     if petsc.precision == 'single':
