@@ -59,7 +59,7 @@ class Primme(package.Package):
     return code
 
 
-  def Check(self,conf,vars,petsc,archdir):
+  def Check(self,slepcconf,slepcvars,petsc,archdir):
     code = self.SampleCode(petsc)
     if self.packagedir:
       dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
@@ -87,9 +87,9 @@ class Primme(package.Package):
         f = ['-I' + includes[0]]
       result = self.Link([],[],l+f,code,' '.join(f),petsc.language)
       if result:
-        conf.write('#define SLEPC_HAVE_PRIMME 1\n')
-        vars.write('PRIMME_LIB = ' + ' '.join(l) + '\n')
-        vars.write('PRIMME_INCLUDE = ' + ' '.join(f) + '\n')
+        slepcconf.write('#define SLEPC_HAVE_PRIMME 1\n')
+        slepcvars.write('PRIMME_LIB = ' + ' '.join(l) + '\n')
+        slepcvars.write('PRIMME_INCLUDE = ' + ' '.join(f) + '\n')
         self.havepackage = True
         self.packageflags = l+f
         self.location = includes[0] if self.packageincludes else i
@@ -98,30 +98,33 @@ class Primme(package.Package):
     self.log.Exit('Unable to link with PRIMME library in directories'+' '.join(dirs)+' with libraries and link flags '+' '.join(libs)+' [NOTE: make sure PRIMME version is 2.0 at least]')
 
 
-  def DownloadAndInstall(self,conf,vars,slepc,petsc,archdir,prefixdir):
+  def DownloadAndInstall(self,slepcconf,slepcvars,slepc,petsc,archdir,prefixdir):
     externdir = slepc.CreateDir(archdir,'externalpackages')
     builddir  = self.Download(externdir,slepc.downloaddir)
 
-    # Configure
-    g = open(os.path.join(builddir,'mymake_flags'),'w')
-    g.write('export LIBRARY     = libprimme.'+petsc.ar_lib_suffix+'\n')
-    g.write('export SOLIBRARY   = libprimme.'+petsc.sl_suffix+'\n')
-    g.write('export SONAMELIBRARY = libprimme.'+petsc.sl_suffix+self.version+'\n')
-    g.write('export CC          = '+petsc.cc+'\n')
+    # Makefile
+    cont =  'export LIBRARY       = libprimme.'+petsc.ar_lib_suffix+'\n'
+    cont += 'export SOLIBRARY     = libprimme.'+petsc.sl_suffix+'\n'
+    cont += 'export SONAMELIBRARY = libprimme.'+petsc.sl_suffix+self.version+'\n'
+    cont += 'export CC            = '+petsc.cc+'\n'
     if hasattr(petsc,'fc'):
-      g.write('export F77         = '+petsc.fc+'\n')
-    g.write('export DEFINES     = ')
+      cont += 'export F77           = '+petsc.fc+'\n'
+    cont += 'export DEFINES       = '
     if petsc.blaslapackmangling == 'underscore':
-      g.write('-DF77UNDERSCORE ')
+      cont += '-DF77UNDERSCORE '
     if petsc.blaslapackint64:
-      g.write('-DPRIMME_BLASINT_SIZE=64')
-    g.write('\n')
-    g.write('export INCLUDE     = \n')
-    g.write('export CFLAGS      = '+petsc.cc_flags.replace('-Wall','').replace('-Wshadow','').replace('-fvisibility=hidden','')+' '+self.buildflags+'\n')
-    g.write('export RANLIB      = '+petsc.ranlib+'\n')
-    g.write('export PREFIX      = '+prefixdir+'\n')
-    g.write('include makefile\n')
-    g.close()
+      cont += '-DPRIMME_BLASINT_SIZE=64'
+    cont += '\n'
+    cont += 'export INCLUDE       = \n'
+    cont += 'export CFLAGS        = '+petsc.cc_flags.replace('-Wall','').replace('-Wshadow','').replace('-fvisibility=hidden','')+' '+self.buildflags+'\n'
+    cont += 'export RANLIB        = '+petsc.ranlib+'\n'
+    cont += 'export PREFIX        = '+prefixdir+'\n'
+    cont += 'include makefile\n'
+    self.log.write('Using makefile definitions:\n')
+    self.log.write(cont)
+    mfile = open(os.path.join(builddir,'mymake_flags'),'w')
+    mfile.write(cont)
+    mfile.close()
 
     # Build package
     target = ' install' if petsc.buildsharedlib else ' lib'
@@ -151,16 +154,16 @@ class Primme(package.Package):
       self.log.Exit('Unable to link with downloaded PRIMME')
 
     # Write configuration files
-    conf.write('#define SLEPC_HAVE_PRIMME 1\n')
-    vars.write('PRIMME_LIB = ' + l + '\n')
-    vars.write('PRIMME_INCLUDE = ' + f + '\n')
+    slepcconf.write('#define SLEPC_HAVE_PRIMME 1\n')
+    slepcvars.write('PRIMME_LIB = ' + l + '\n')
+    slepcvars.write('PRIMME_INCLUDE = ' + f + '\n')
 
     self.location = incdir
     self.havepackage = True
     self.packageflags = [l] + [f]
 
 
-  def LoadVersion(self,conf):
+  def LoadVersion(self,slepcconf):
     try:
       f = open(os.path.join(self.location,'primme.h'))
       for l in f.readlines():
@@ -173,6 +176,6 @@ class Primme(package.Package):
       f.close()
       self.iversion = major + '.' + minor
       if major=='3':
-        conf.write('#define SLEPC_HAVE_PRIMME3 1\n')
+        slepcconf.write('#define SLEPC_HAVE_PRIMME3 1\n')
     except: pass
 
