@@ -3,18 +3,18 @@
 
 #define SLEPC_VERSION_RELEASE    1
 #define SLEPC_VERSION_MAJOR      3
-#define SLEPC_VERSION_MINOR      13
-#define SLEPC_VERSION_SUBMINOR   4
+#define SLEPC_VERSION_MINOR      14
+#define SLEPC_VERSION_SUBMINOR   1
 #define SLEPC_VERSION_PATCH      0
-#define SLEPC_RELEASE_DATE       "March 31, 2020"
-#define SLEPC_VERSION_DATE       "Sep 02, 2020"
+#define SLEPC_RELEASE_DATE       "September 30, 2020"
+#define SLEPC_VERSION_DATE       "Dec 08, 2020"
 
 #if !defined (SLEPC_VERSION_GIT)
-#define SLEPC_VERSION_GIT        "v3.13.4"
+#define SLEPC_VERSION_GIT        "v3.14.1"
 #endif
 
 #if !defined(SLEPC_VERSION_DATE_GIT)
-#define SLEPC_VERSION_DATE_GIT   "2020-09-02 16:58:00 +0200"
+#define SLEPC_VERSION_DATE_GIT   "2020-12-08 19:11:10 +0100"
 #endif
 
 #define SLEPC_VERSION_EQ(MAJOR,MINOR,SUBMINOR) \
